import { readFileSync } from 'fs'
import { Config } from './types'

const CONFIG_FILE_NAME = '.gcp-functions'

const defaultConfig: Config = {
  functionsDir: './functions',
  buildDir: './functions/build',
  runtime: 'nodejs20',
  region: 'europe-west6',
  env: [],
  prefix: '',
  generation: 1,
  memory: undefined,
  timeout: undefined,
}

function readConfig() {
  try {
    const config = JSON.parse(readFileSync(CONFIG_FILE_NAME).toString())

    return (Object.keys(defaultConfig) as (keyof Config)[]).reduce(
      (acc, key) => {
        if (config[key]) {
          acc[key] = config[key]
        }

        return acc
      },
      {} as Record<keyof Config, unknown>
    )
  } catch (e) {
    return {}
  }
}

export const config = {
  ...defaultConfig,
  ...readConfig(),
}
