import { execSync } from 'child_process'
import { readdirSync } from 'fs'
import { join } from 'path'
import { config } from '../config'
import ora from 'ora'

export function deploy() {
  const spinner = ora('Deploying functions').start()

  const functions = readdirSync(config.functionsDir).filter((f) =>
    f.endsWith('.ts')
  )

  for (const functionFile of functions) {
    const functionName = functionFile.replace('.ts', '')
    const functionNameWithPrefix = `${config.prefix}${
      config.prefix ? '-' : ''
    }${functionName}`

    spinner.text = `Deploying ${functionName}`

    config.env.forEach((e) => {
      if (!process.env[e]) {
        throw new Error(`Missing environment variable ${e}`)
      }
    })

    const options = [
      `--runtime ${config.runtime}`,
      `--trigger-http`,
      `--region=${config.region}`,
      `--allow-unauthenticated`,
      `--source=${join(config.buildDir, functionName)}`,
      `--entry-point=${functionName}`,
      ...config.env.map(
        (e: string) => `--set-env-vars="${e}=${process.env[e]}"`
      ),
    ]

    if (config.generation === 2) {
      options.push('--gen2')
    }

    if (config.memory) {
      options.push(`--memory=${config.memory}`)
    }

    if (config.timeout) {
      options.push(`--timeout=${config.timeout}`)
    }

    execSync(
      `gcloud functions deploy ${functionNameWithPrefix} \
      ${options.join('\\')}`
    )

    spinner.succeed(`Deployed ${functionName}`)
  }
}
